@@ -10,7 +10,7 @@ use parent qw(
     IO::Async::Notifier
 );
 
-our $VERSION = '2.002_002'; # TRIAL VERSION
+our $VERSION = '2.002_003'; # TRIAL VERSION
 
 =encoding utf8
 
@@ -263,7 +263,8 @@ async sub execute_command {
 
 =head1 AUTHOR
 
-Tom Molesworth C<< <TEAM@cpan.org> >>.
+Tom Molesworth C<< <TEAM@cpan.org> >> plus contributors as mentioned in
+L<Net::Async::Redis/CONTRIBUTORS>.
 
 =head1 LICENSE
 
