@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(IO::Async::Notifier);
 
-our $VERSION = '2.002_002'; # TRIAL VERSION
+our $VERSION = '2.002_003'; # TRIAL VERSION
 
 =head1 NAME
 
@@ -35,7 +35,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <TEAM@cpan.org>
+Tom Molesworth C<< <TEAM@cpan.org> >> plus contributors as mentioned in
+L<Net::Async::Redis/CONTRIBUTORS>.
 
 =head1 LICENSE
 
