@@ -3,7 +3,7 @@ package Net::Async::Redis::Server::Database;
 use strict;
 use warnings;
 
-our $VERSION = '2.002_002'; # TRIAL VERSION
+our $VERSION = '2.002_003'; # TRIAL VERSION
 
 =head1 NAME
 
@@ -12,7 +12,8 @@ Net::Async::Redis::Server::Database - implementation for database-related Redis
 =head1 DESCRIPTION
 
 See L<Net::Async::Redis::Commands> for the full list of commands.
-Not all of them will be implemented yet.
+
+Most of them are not yet implemented.
 
 =cut
 
@@ -144,3 +145,12 @@ sub brpoplpush : method {
 
 1;
 
+=head1 AUTHOR
+
+Tom Molesworth C<< <TEAM@cpan.org> >> plus contributors as mentioned in
+L<Net::Async::Redis/CONTRIBUTORS>.
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2015-2020. Licensed under the same terms as Perl itself.
+
